summaryrefslogtreecommitdiff
path: root/include/mbgl
diff options
context:
space:
mode:
Diffstat (limited to 'include/mbgl')
-rw-r--r--include/mbgl/platform/platform.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/mbgl/platform/platform.hpp b/include/mbgl/platform/platform.hpp
index b4aaccb8bd..024771cc7c 100644
--- a/include/mbgl/platform/platform.hpp
+++ b/include/mbgl/platform/platform.hpp
@@ -17,8 +17,8 @@ std::string uppercase(const std::string &string);
// Lowercase a string, potentially using platform-specific routines.
std::string lowercase(const std::string &string);
-// Returns the path to the default cache database on this system.
-std::string defaultCacheDatabase();
+// Returns the path to the default shader cache on this system.
+std::string defaultShaderCache();
std::string applicationRoot();